@@ -1,12 +1,11 @@
 package Fey::Meta::Class::Table;
-{
-  $Fey::Meta::Class::Table::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.47';
+
 use Fey::Exceptions qw( param_error );
 use Fey::Hash::ColumnsKey;
 use Fey::Object::Policy;
@@ -185,13 +184,13 @@ sub _ClassForTable {
 
         return $class_name
             if $potential_table->name() eq $table->name()
-                && $potential_table->schema()->name() eq
-                $table->schema()->name();
+            && $potential_table->schema()->name() eq $table->schema()->name();
     }
 
     return;
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _search_cache {
     my $self = shift;
     my $p    = shift;
@@ -202,7 +201,7 @@ sub _search_cache {
         my @names = map { $_->name() } @{$key};
         next unless all { defined $p->{$_} } @names;
 
-        my $cache_key = join "\0", map { $_, $p->{$_} } sort @names;
+        my $cache_key = join "\0", map { ( $_, $p->{$_} ) } sort @names;
 
         return $cache->{$cache_key}
             if exists $cache->{$cache_key};
@@ -218,7 +217,7 @@ sub _write_to_cache {
     for my $key ( @{ $self->table()->candidate_keys() } ) {
         my @names = map { $_->name() } @{$key};
 
-        my @pieces = map { $_, $object->$_() } sort @names;
+        my @pieces = map { ( $_, $object->$_() ) } sort @names;
 
         next unless all {defined} @pieces;
 
@@ -248,8 +247,8 @@ sub _associate_table {
 
     param_error 'You must load your schema class before calling has_table()'
         unless $class
-            && $class->can('meta')
-            && $class->meta()->_has_schema();
+        && $class->can('meta')
+        && $class->meta()->_has_schema();
 
     param_error
         'A table object passed to has_table() must have at least one key'
@@ -261,6 +260,7 @@ sub _associate_table {
 
     $self->_make_column_attributes($context);
 }
+## use critic;
 
 sub _make_column_attributes {
     my $self    = shift;
@@ -351,6 +351,7 @@ sub _add_transform {
     }
 }
 
+## no critic (Subroutines::ProhibitManyArgs)
 sub _add_inflator_to_attribute {
     my $self     = shift;
     my $name     = shift;
@@ -388,15 +389,15 @@ sub _add_inflator_to_attribute {
 
     $self->add_attribute(
         $name,
-        metaclass     => 'Fey::Meta::Attribute::FromInflator',
-        is            => 'ro',
-        lazy          => 1,
-        default       => $default,
-        predicate     => $inflated_predicate,
-        clearer       => $inflated_clear,
-        init_arg      => undef,
-        raw_attribute => $raw_attr,
-        inflator      => $inflator,
+        metaclass          => 'Fey::Meta::Attribute::FromInflator',
+        is                 => 'ro',
+        lazy               => 1,
+        default            => $default,
+        predicate          => $inflated_predicate,
+        clearer            => $inflated_clear,
+        init_arg           => undef,
+        raw_attribute      => $raw_attr,
+        inflator           => $inflator,
         definition_context => $context,
         %handles,
     );
@@ -412,6 +413,7 @@ sub _add_inflator_to_attribute {
 
     $self->_add_inflator( $name => $inflator );
 }
+## use critic
 
 sub add_has_one {
     my $self = shift;
@@ -539,6 +541,7 @@ sub make_immutable {
 }
 
 if ( $Moose::VERSION >= 1.9900 ) {
+
     # XXX - can we refactor Moose/CMOP core to make overriding (and copying)
     # all of this unnecessary?
     override _inline_new_object => sub {
@@ -600,7 +603,8 @@ sub _inline_search_cache {
 sub _inline_write_to_cache {
     my $self = shift;
 
-    return '$metaclass->_write_to_cache($instance) if $metaclass->_object_cache_is_enabled();';
+    return
+        '$metaclass->_write_to_cache($instance) if $metaclass->_object_cache_is_enabled();';
 }
 
 __PACKAGE__->meta()->make_immutable();
@@ -619,7 +623,7 @@ Fey::Meta::Class::Table - A metaclass for table classes
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -712,7 +716,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Dave Rolsky.
+This software is copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
