@@ -1,12 +1,11 @@
 package Fey::Meta::HasMany::ViaFK;
-{
-  $Fey::Meta::HasMany::ViaFK::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.47';
+
 use Fey::ORM::Types qw( ArrayRef );
 use List::AllUtils qw( any );
 
@@ -21,6 +20,7 @@ has 'order_by' => (
     isa => ArrayRef,
 );
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _make_iterator_maker {
     my $self = shift;
 
@@ -28,7 +28,7 @@ sub _make_iterator_maker {
 
     my $select = $self->associated_class()->schema_class()->SQLFactoryClass()
         ->new_select();
-    $select->select($target_table)->from($target_table);
+    $select->select( $target_table->columns() )->from($target_table);
 
     my @ph_names;
 
@@ -53,6 +53,7 @@ sub _make_iterator_maker {
         $bind_params_sub,
     );
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -70,7 +71,7 @@ Fey::Meta::HasMany::ViaFK - A parent for has-one metaclasses based on a L<Fey::F
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 DESCRIPTION
 
@@ -123,7 +124,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Dave Rolsky.
+This software is copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
