@@ -1,20 +1,21 @@
 package Fey::Meta::Method::Constructor;
-{
-  $Fey::Meta::Method::Constructor::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.47';
+
 use Moose;
 
 extends 'Moose::Meta::Method::Constructor';
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _expected_method_class {
     return 'Fey::Object::Table';
 }
 
+## no critic (BuiltinFunctions::ProhibitStringyEval, ErrorHandling::RequireCheckingReturnValueOfEval)
 if ( $Moose::VERSION < 1.9900 ) {
     eval <<'EOF';
 # XXX - This is copied straight from Moose 0.36 because there's no
@@ -148,4 +149,6 @@ else {
     };
 }
 
+__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
+
 1;
