@@ -1,16 +1,14 @@
 package Fey::ORM::Types;
-{
-  $Fey::ORM::Types::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 
 use base 'MooseX::Types::Combine';
 
+our $VERSION = '0.47';
+
 __PACKAGE__->provide_types_from(
-    qw( MooseX::Types::Moose Fey::ORM::Types::Internal )
-);
+    qw( MooseX::Types::Moose Fey::ORM::Types::Internal ));
 
 1;
 
@@ -26,7 +24,7 @@ Fey::ORM::Types - Types for use in Fey::ORM
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 DESCRIPTION
 
@@ -44,7 +42,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Dave Rolsky.
+This software is copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
