@@ -1,11 +1,10 @@
 package Fey::ORM::Types::Internal;
-{
-  $Fey::ORM::Types::Internal::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.47';
+
 use MooseX::Types -declare => [
     qw(
         ArrayRefOfClasses
@@ -17,11 +16,10 @@ use MooseX::Types -declare => [
         )
 ];
 
-use MooseX::Types::Moose
-    qw( ArrayRef ClassName Object Undef );
+use MooseX::Types::Moose qw( ArrayRef ClassName Object Undef );
 
 role_type DoesHasMany, { role => 'Fey::Meta::Role::Relationship::HasMany' };
-role_type DoesHasOne, { role => 'Fey::Meta::Role::Relationship::HasOne' };
+role_type DoesHasOne,  { role => 'Fey::Meta::Role::Relationship::HasOne' };
 
 #<<<
 subtype TableWithSchema,
@@ -74,7 +72,7 @@ Fey::ORM::Types::Internal - Types for use in Fey::ORM
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 DESCRIPTION
 
@@ -92,7 +90,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Dave Rolsky.
+This software is copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
