@@ -1,13 +1,13 @@
 package Fey::Object::Schema;
-{
-  $Fey::Object::Schema::VERSION = '0.46';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.47';
+
 use Fey::Meta::Class::Table;
+use Try::Tiny;
 
 use Moose;
 
@@ -55,7 +55,7 @@ sub RunInTransaction {
 
     my @r;
 
-    eval {
+    try {
         $dbh->begin_work()
             unless $in_tran;
 
@@ -71,13 +71,12 @@ sub RunInTransaction {
 
         $dbh->commit()
             unless $in_tran;
-    };
-
-    if ( my $e = $@ ) {
+    }
+    catch {
         $dbh->rollback
             unless $in_tran;
-        die $e;
-    }
+        die $_;
+    };
 
     return unless defined $wantarray;
 
@@ -130,7 +129,7 @@ Fey::Object::Schema - Base class for schema-based objects
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -206,7 +205,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Dave Rolsky.
+This software is copyright (c) 2011 - 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
